##  Configure Advanced Filters
Configure advanced filters using a single attribute to unlock additional insights. For example:
  * Filtering by lifecycle
  * Filtering by hierarchy level
  * Filtering by functional or technical fit


You can create views for individual attributes to narrow the data scope for calculating KPIs. For example, consider the KPI "TIME: application rationalization." The drilldown at level 2 includes:
  * The number of applications linked to business capabilities, sorted by their hierarchy level.
  * Applications stacked with the TIME classifications "Eliminate" and "Tolerate."


You can create views that exclude specific hierarchy levels to focus your KPI analysis. This approach allows for targeted evaluations. Let's consider an example for a specific region. To create advanced filters, follow these steps:
  1. Create a view for “Asia” with all hierarchy levels to assess performance across the region. Add the view to the "Regions" group.
  2. Create a view for “Asia (hierarchy level 1)” filtered to business capabilities in the first hierarchy level and applications in "Phase in" or "Active" lifecycle phases. This provides an extra level of scope into the data.
  3. Create a view for “Asia (hierarchy level 4)” filtered to business capabilities in the fourth hierarchy level. You can then examine the data in the second level of drilldown focused on that hierarchy level.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9ef7b3c3598844ebb344db855d9a16ec_LowRes.png)
Example Views for Regions, Teams, and Business Units
